@@ -462,7 +462,7 @@ class DatabaseAccess(object):
         row = result.fetchall()
         if not self._keep_connection:
             self.conn.close()
-        return [dict(zip(col.keys(), col.values())) for col in row]
+        return [dict(zip(col.keys(), col._mapping.values())) for col in row]
 
     def item_update(self, par_dict, item_id):
         """
@@ -683,7 +683,7 @@ class DatabaseAccess(object):
         row = result.fetchall()
         if not self._keep_connection:
             self.conn.close()
-        return [dict(zip(col.keys(), col.values())) for col in row]
+        return [dict(zip(col.keys(), col._mapping.values())) for col in row]
 
     def get_job_status(self, job_id):
         try:
